<?php

/**
 * WooCommerce Compatibility File
 *
 * @link https://woocommerce.com/
 *
 * @package Meditest
 */

/**
 * WooCommerce setup function.
 *
 * @link https://docs.woocommerce.com/document/third-party-custom-theme-compatibility/
 * @link https://github.com/woocommerce/woocommerce/wiki/Enabling-product-gallery-features-(zoom,-swipe,-lightbox)
 * @link https://github.com/woocommerce/woocommerce/wiki/Declaring-WooCommerce-support-in-themes
 *
 * @return void
 */

/**
 * Set default number of columns in WooCommerce product archives using add_theme_support.
 */
function meditest_woocommerce_setup()
{
	// Define the default number of columns you want.
	$default_columns = 3;

	// Get the current theme name.
	$current_theme = wp_get_theme()->get('Name');

	// Check if WooCommerce is active and the current theme is the one you want to target.
	if (class_exists('WooCommerce') && $current_theme === 'Meditest') {
		// Add theme support for WooCommerce.
		add_theme_support('woocommerce', array(
			'thumbnail_image_width' => 300,
			'single_image_width'    => 600,
			'product_grid'          => array(
				'default_columns' => $default_columns, // Set the default number of columns.
				'default_rows'    => 3,
				'min_columns'     => 2,
				'max_columns'     => 6,
				'default_rows'    => 3,
				'min_rows'        => 2,
				'max_rows'        => 8,
			),
		));
	}

	add_theme_support('wc-product-gallery-zoom');
	add_theme_support('wc-product-gallery-lightbox');
	add_theme_support('wc-product-gallery-slider');
}
add_action('after_setup_theme', 'meditest_woocommerce_setup');


/**
 * Register widget area for shop page.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function meditest_woocommerce_widgets_init()
{

	register_sidebar(array(
		'name' => esc_html__('Shop Sidebar', 'meditest'),
		'id' => 'shop-sidebar',
		'description' => esc_html__('Meditest Shop Sidebar Widget.', 'meditest'),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',

	));
}
add_action('widgets_init', 'meditest_woocommerce_widgets_init');


/**
 * WooCommerce specific scripts & stylesheets.
 *
 * @return void
 */
function meditest_woocommerce_scripts()
{
	wp_enqueue_style('meditest-woocommerce-style', get_template_directory_uri() . '/woocommerce.css', array(), MEDITEST_VERSION);

	$font_path   = WC()->plugin_url() . '/assets/fonts/';
	$inline_font = '@font-face {
			font-family: "star";
			src: url("' . $font_path . 'star.eot");
			src: url("' . $font_path . 'star.eot?#iefix") format("embedded-opentype"),
				url("' . $font_path . 'star.woff") format("woff"),
				url("' . $font_path . 'star.ttf") format("truetype"),
				url("' . $font_path . 'star.svg#star") format("svg");
			font-weight: normal;
			font-style: normal;
		}';

	wp_add_inline_style('meditest-woocommerce-style', $inline_font);
}
add_action('wp_enqueue_scripts', 'meditest_woocommerce_scripts');


/**
 * Add 'woocommerce-active' class to the body tag.
 *
 * @param  array $classes CSS classes applied to the body tag.
 * @return array $classes modified to include 'woocommerce-active' class.
 */
function meditest_woocommerce_active_body_class($classes)
{
	$classes[] = 'woocommerce-active';

	return $classes;
}
add_filter('body_class', 'meditest_woocommerce_active_body_class');

/**
 * Related Products Args.
 *
 * @param array $args related products args.
 * @return array $args related products args.
 */
function meditest_woocommerce_related_products_args($args)
{
	$defaults = array(
		'posts_per_page' => 3,
		'columns'        => 3,
	);

	$args = wp_parse_args($defaults, $args);

	return $args;
}
add_filter('woocommerce_output_related_products_args', 'meditest_woocommerce_related_products_args');

/**
 * Remove default WooCommerce wrapper.
 */
remove_action('woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10);
remove_action('woocommerce_before_main_content', 'woocommerce_breadcrumb', 20);
remove_action('woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10);

if (!function_exists('meditest_woocommerce_wrapper_before')) {
	/**
	 * Before Content.
	 *
	 * Wraps all WooCommerce content in wrappers which match the theme markup.
	 *
	 * @return void
	 */
	function meditest_woocommerce_wrapper_before()
	{
?>
		<main class="site-main meditest_shop">
		<?php
	}
}
add_action('woocommerce_before_main_content', 'meditest_woocommerce_wrapper_before');

if (!function_exists('meditest_woocommerce_wrapper_after')) {
	/**
	 * After Content.
	 *
	 * Closes the wrapping divs.
	 *
	 * @return void
	 */
	function meditest_woocommerce_wrapper_after()
	{
		?>

		</main><!-- #main -->
	<?php
	}
}
add_action('woocommerce_after_main_content', 'meditest_woocommerce_wrapper_after');


/**
 * Sample implementation of the WooCommerce Mini Cart.
 *
 * You can add the WooCommerce Mini Cart to header.php like so ...
 *
	<?php
		if ( function_exists( 'meditest_woocommerce_header_cart' ) ) {
			meditest_woocommerce_header_cart();
		}
	?>
 */

if (!function_exists('meditest_woocommerce_header_cart')) {
	/**
	 * Display Header Cart.
	 *
	 * @return void
	 */
	function meditest_woocommerce_header_cart()
	{
		if (is_cart()) {
			$class = 'current-menu-item';
		} else {
			$class = '';
		}
	?>
		<ul id="site-header-cart" class="site-header-cart">
			<li class="<?php echo esc_attr($class); ?>">
				<div class="mini-cart-icon-wrap">
					<span class="mini-cart-icon"><i class="ri-shopping-cart-2-line"></i></span>
					<span class="mini-cart-count"><?php echo esc_html(WC()->cart->get_cart_contents_count()); ?></span>
				</div>
			</li>
			<li>
				<?php
				$instance = array(
					'title' => 'Cart',
				);

				the_widget('WC_Widget_Cart', $instance);
				?>
			</li>
		</ul>
<?php
	}
}

// Remove default add to cart button from template shop loop
remove_action('woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart', 10);


// Remove YITH Quick View button from shop loop

if (class_exists('YITH_WCQV')) {
	// YITH Woocommerce Wishlist plugin is active

	function remove_yith_quick_view_button()
	{
		remove_action('woocommerce_after_shop_loop_item', array(YITH_WCQV_Frontend(), 'yith_add_quick_view_button'), 15);
	}
	add_action('init', 'remove_yith_quick_view_button');
}


// Product Template Loop Add to cart, Quick View, Add to wishlist icon button link
if (!function_exists('meditest_template_loop_icon_set')) {
	function meditest_template_loop_icon_set()
	{
		global $product;
		$product_id = $product->get_id();

		$product_permalink = get_permalink($product_id);
		$add_to_cart_url = $product->add_to_cart_url();

		if (class_exists('YITH_WCWL')) {
			$meditest_yith_wl = do_shortcode("[yith_wcwl_add_to_wishlist]");
		} else {
			$meditest_yith_wl = '';
		}

		echo '<div class="meditest_template_loop_product_action_btn"><a href="' . esc_url($add_to_cart_url) . '" data-quantity="1" class="button product_type_simple add_to_cart_button ajax_add_to_cart" data-product_id="' . esc_attr($product_id) . '" data-product_sku="' . esc_attr($product->get_sku()) . '" ><i class="ri-shopping-cart-2-line"></i></a> ' . $meditest_yith_wl . ' 	<a href="#" class="button yith-wcqv-button" data-product_id="' . esc_attr($product_id) . '"><i class="icon-eye1"></i></a>	</div>';
	}
}
add_action('woocommerce_after_shop_loop_item', 'meditest_template_loop_icon_set', 10);


// Quantity Plus Minus Button
add_action('woocommerce_after_quantity_input_field', 'meditest_display_quantity_plus');

function meditest_display_quantity_plus()
{
	echo '<div class="meditest_qpm"><button type="button" class="plus">+</button>';
	echo '<button type="button" class="minus">-</button></div>';
}


// -------------
// 2. Trigger update quantity script

add_action('wp_footer', 'meditest_add_cart_quantity_plus_minus');

function meditest_add_cart_quantity_plus_minus()
{

	if (!is_product() && !is_cart()) return;

	wc_enqueue_js("   
           
      $(document).on( 'click', 'button.plus, button.minus', function() {
  
         var qty = $( this ).closest( '.quantity' ).find( '.qty' );
         var val = parseFloat(qty.val());
         var max = parseFloat(qty.attr( 'max' ));
         var min = parseFloat(qty.attr( 'min' ));
         var step = parseFloat(qty.attr( 'step' ));
 
         if ( $( this ).is( '.plus' ) ) {
            if ( max && ( max <= val ) ) {
               qty.val( max ).change();
            } else {
               qty.val( val + step ).change();
            }
         } else {
            if ( min && ( min >= val ) ) {
               qty.val( min ).change();
            } else if ( val > 1 ) {
               qty.val( val - step ).change();
            }
         }
 
      });
      ");
}
